@@ -23,13 +23,18 @@
 
 #include <math.h>
 #include <stdlib.h>
+#include <glib.h>
 #include <gtk/gtk.h>
 #include <gdk/gdk.h>
 #include <gdk/gdkkeysyms.h>
+#include <gtkgl/gtkglarea.h>
 #include <GL/gl.h>
 #include <GL/glu.h>
 
-#include <gtkgl/gtkglarea.h>
+#ifndef M_PI
+#define M_PI 3.14
+#endif
+
 
 /* #define FULLSCREEN_MESA_3DFX    /* uncomment this to get 3DFX acceleration */
 
@@ -50,6 +55,8 @@ typedef struct {
 
 /* game state */
 
+GTimer *gtimer = NULL;
+
 double game_time;
 double game_tick;
 int draw_fast = 0;
@@ -106,7 +113,11 @@ void game_init()
 {
   int i;
 
-  game_time = gdk_time_get() / 1000.0;
+  if (!gtimer)
+    gtimer = g_timer_new();
+  g_timer_reset(gtimer);
+
+  game_time = g_timer_elapsed(gtimer, NULL);
   game_tick  = 1.0 / 60;
 
   wave_cnt = 0;
@@ -148,7 +159,7 @@ void game_play()
   double time_now,tick_now;
 
   /* timing */
-  time_now = gdk_time_get() / 1000.0;
+  time_now = g_timer_elapsed(gtimer, NULL);
   tick_now = time_now - game_time;
   if (tick_now < 0.001) tick_now = 0.001;
   if (tick_now > 0.2  ) tick_now = 0.2;
@@ -719,11 +730,14 @@ gint init(GtkWidget *widget)
 {
   /* OpenGL functions can be called only if makecurrent returns true */
   if (gtk_gl_area_make_current(GTK_GL_AREA(widget))) {
+#if !defined(WIN32)
     GdkFont *font;
+#endif
 
     /* set viewport */
     glViewport(0,0, widget->allocation.width, widget->allocation.height);
 
+#if !defined(WIN32)
     /* generate font display lists */
     font = gdk_font_load("-adobe-helvetica-medium-r-normal--*-120-*-*-*-*-*-*");
     if (font) {
@@ -731,6 +745,7 @@ gint init(GtkWidget *widget)
       gdk_gl_use_gdk_font(font, 0, 128, fontbase);
       gdk_font_unref(font);
     }
+#endif
   }
   return TRUE;
 }
@@ -844,6 +859,9 @@ int main(int argc, char **argv)
   */
   int attrlist[] = {
     GDK_GL_RGBA,
+    GDK_GL_RED_SIZE,1,
+    GDK_GL_GREEN_SIZE,1,
+    GDK_GL_BLUE_SIZE,1,
     GDK_GL_DOUBLEBUFFER,
     GDK_GL_NONE
   };
